The 4 Stocks That Slimmed the DJIA Monday Slide - Home Depot (NYSE:HD) - 24/7 Wall St.
Description: Source: thinkstockDecember 28, 2014: Markets opened lower on Monday as neither the bulls nor the bears can gin up a lot of support. Volumes are low and corporate news is nearly non-existent. Crude oil started the day higher, but has drifted to a loss of about 2% as the day wore on. Shortly before the […]
Keywords: Investing, BA, BA stock, BA ticker, BA news, CSCO, CSCO stock, CSCO ticker, CSCO news, HD, HD stock, HD ticker, HD news, JPM, JPM stock, JPM ticker, JPM news, market close

24/7 Wall St. - Insightful Analysis and Commentary for U.S. and Global Equity Investors
Free Daily Newsletter
Terms & Conditions

# The 4 Stocks That Slimmed the DJIA Monday Slide

By Paul Ausick December 29, 2014 4:08 pm EST

Print
Email
Tweet

December 28, 2014: Markets opened lower on Monday as neither the bulls nor the bears can gin up a lot of support. Volumes are low and corporate news is nearly non-existent. Crude oil started the day higher, but has drifted to a loss of about 2% as the day wore on. Shortly before the closing bell the DJIA traded down 0.08% for the day, the S&P 500 traded up 0.09%, and the Nasdaq Composite traded flat. International Business Machines Corp. (NYSE: IBM) dropped more than 1% today and its high per share price pushed the DJIA lower just as the market closed.

The DJIA stock posting the largest daily gain ahead of the close Monday was The Home Depot Inc. (NYSE: HD) which traded up 0.87% at $104.64. The stock’s 52-week range is $73.96 to $104.80, and the high was posted early Monday. Trading volume was less than half the daily average of around 5.8 million shares. Reports of solid sales at home improvement stores during the holidays have helped push this stock higher today.

JPMorgan Chase & Co. (NYSE: JPM) traded up 0.77% at $63.03. The stock’s 52-week range is $52.97 to $63.34, and the high was set today. Trading volume was about 50% below the daily average of around 26 million shares. The big bank is one of the underwriters for the IPO of Shake Shack which was announced today.

The Boeing Co. (NYSE: BA) traded higher by 0.71% at $132.57. The stock’s 52-week range is $116.32 to $144.57. Volume was less than half the daily average of around 4.4 million shares. The company held its first test flight on Sunday of a new Air Force Tanker.

Cisco Systems Inc. (NASDAQ: CSCO) traded up 0.48% at $28.49. The stock’s 52-week range is $21.27 to $28.59. Trading volume about 60% below the daily average of around 29 million shares. The stock missed matching its 52-week high by just a couple of pennies and was touted as a Rocket Stock at thestreet.com today.

Of the Dow 30 stocks 13 are set to close higher today and 17 are on track to close lower.

ALSO READ: 5 Top Tech Stocks for 2015 With Potential Big Catalysts

By Paul Ausick

Buzz up! Digg Fark Facebook Reddit Tumblr
Read more: Investing, market close, The Boeing Company (NYSE:BA), Cisco Systems, Inc. (NASDAQ:CSCO), Home Depot (NYSE:HD), JPMorgan Chase & Co. (NYSE:JPM)
comments powered by Disqus

- ### Recent Posts

  - The 52-Week Low Club for Friday
  - The 4 Stocks That Weighed Down the DJIA Friday
  - GM Closes Out 2014 With Total 84 Recalls for 30 Million Vehicles
  - Can India Outperform Again in 2015?
  - Casino Stocks Hammered on Macau Data
  - Apple Gets First Analyst Price Target Hike of 2015
  - November New Construction Spending Unexpectedly Drops
  - What Terminating Licenses Will Mean for Ballard Power
  - Russian Oil Production Sets Post-Soviet High
  - Why Wells Fargo 2015 Semiconductor Outlook Is Optimistic but Cautious
- Get Quote for:
  Symbol Lookup
  Search

x